@@ -1,19 +1,12 @@
  
-# 0.01  2012-xx-yy
-
-
-# 0.01  2012-06-23  o initial release
-
-
-#-------------------------------------------------------
-
 
 
 ##NS export(dif.logistic.regression)
 #---------------------------------------------------------------------------------------##
 # This function performs itemwise DIF analysis by using logistic regression methods     ##
 # uniform and nonuniform DIF                                                            ##
-dif.logistic.regression <- function( dat , group , score ){
+dif.logistic.regression <- function( dat , group , score ,
+		quant=1.645){
     # INPUT:
     # dat       ... data frame (must only include item responses)
     # group     ... group identifier (this has to be a dummy variable)
@@ -21,6 +14,7 @@ dif.logistic.regression <- function( dat , group , score ){
     
     I <- ncol(dat)
     matr <- NULL
+	cat("Items ")
     for (ii in 1:I){
      # ii <- 6
         dat.ii <- na.omit(data.frame( "y" = dat[,ii] , "score" = score , "group" = group ))
@@ -46,19 +40,23 @@ dif.logistic.regression <- function( dat , group , score ){
         a1 <- aggregate( dat[,ii] , list( group) , mean , na.rm=T )[,2]
 		h1$pR <- a1[1]
 		h1$pF <- a1[2]
+		h1$pdiff <- h1$pR - h1$pF
 		h1$pdiff.adj <- NA	
 		h1$uniformDIF <- mod2$coef[3]
 		h1$se.uniformDIF <- sqrt( diag( vcov(mod2)) )[3]
 		h1$t.uniformDIF <- mod2$coef[3] / sqrt( diag( vcov(mod2) ) )[3] 
 		h1$sig.uniformDIF <- ""
-		if ( h1$t.uniformDIF > 1.96 ){ h1$sig.uniformDIF <- "+" }
-		if ( h1$t.uniformDIF < - 1.96 ){ h1$sig.uniformDIF <- "-" }
+		if ( h1$t.uniformDIF > quant ){ h1$sig.uniformDIF <- "+" }
+		if ( h1$t.uniformDIF < - quant ){ h1$sig.uniformDIF <- "-" }
+		h1$DIF.ETS <- ""
+		#****
+		# nonuniform DIF
 		h1$nonuniformDIF <- mod3$coef[4]
 		h1$se.nonuniformDIF <- sqrt( diag( vcov(mod3)) )[4]
 		h1$t.nonuniformDIF <- mod3$coef[4] / sqrt( diag( vcov(mod3) ) )[4] 
 		h1$sig.nonuniformDIF <- ""
-		if ( h1$t.nonuniformDIF > 1.96 ){ h1$sig.nonuniformDIF <- "+" }
-		if ( h1$t.nonuniformDIF < - 1.96 ){ h1$sig.nonuniformDIF <- "-" }
+		if ( h1$t.nonuniformDIF > quant ){ h1$sig.nonuniformDIF <- "+" }
+		if ( h1$t.nonuniformDIF < - quant ){ h1$sig.nonuniformDIF <- "-" }
 		matr <- rbind( matr , h1 )
         cat( ii , " " ) ; flush.console()
         if ( ii %% 15 == 0 ){ cat("\n") }
@@ -67,6 +65,31 @@ dif.logistic.regression <- function( dat , group , score ){
     # include variable of adjusted p values
 #    ind <- which( colnames(matr) == "pF" )       
     matr[ , "pdiff.adj" ] <- matr$pR - matr$pF - mean( matr$pR - matr$pF  )   
+	ind1 <- grep( "ETS" , colnames(matr) )
+	#***
+	# DIF ETS classifiaction
+	stat <- abs( matr$uniformDIF )
+	stat.low <- stat - quant * matr$se.uniformDIF
+	matr[,"DIF.ETS"] <- "B"
+	# DIF classification C
+	ind <- which( ( stat > .64 ) & ( stat.low > .43 ) )
+	if (length(ind) > 0){ matr[ind, "DIF.ETS"] <- "C" }
+	# DIF classification A
+	ind <- which( ( stat < .43 ) | ( stat.low < 0 ) )
+	if (length(ind) > 0){ matr[ind, "DIF.ETS"] <- "A" }
+	matr$DIF.ETS <- paste0( matr$DIF.ETS , 
+			ifelse( matr$uniformDIF > 0 , "+" , "-" )	 )
+	#*********************************
+	# calculation of DIF variance
+    dif1 <- dif.variance( dif=matr$uniformDIF , se.dif = matr$se.uniformDIF )		
+	matr <- data.frame( matr[ , seq(1,ind1)] , "uniform.EBDIF" = dif1$eb.dif ,
+		"DIF.SD" = dif1$unweighted.DIFSD , matr[ , seq(ind1+1 , ncol(matr)) ] )
+	cat( paste0("\nDIF SD = " , round( 	dif1$unweighted.DIFSD , 3 ) ) , "\n")
+	# sorting of the items
+	g1 <- rank( matr$uniformDIF )
+	matr <- data.frame( "itemnr" = 1:nrow(matr) ,
+			"sortDIFindex" = g1 , 
+				matr )
     # matr <- data.frame( "item" = colnames(dat) , matr )
     return(matr)
     }
