@@ -367,7 +367,7 @@ smirt <- function( dat , Qmatrix , irtmodel="noncomp" ,
 		"n.ik"=n.ik ,  "iter"=iter , "dat2"=dat2 , "dat2.resp"=dat2.resp , 
 		"dat" = dat0 , 
 		"I"=I , "D"=D , "K"=K ,  "theta.k" = theta.k , "pi.k"=pi.k , 
-		"irtmodel"=irtmodel , "s1"=s1 , "s2"=s2 
+		"irtmodel"=irtmodel , "Qmatrix" = Qmatrix , "s1"=s1 , "s2"=s2 
 				)
 	class(res) <- "smirt"
 	return(res)
