@@ -1,5 +1,5 @@
 
-tetrachoric2 <- function( dat , delta=.007 , maxit = 1000000 ,
+tetrachoric2 <- function( dat , method="Tu" ,  delta=.007 , maxit = 1000000 ,
 	cor.smooth=TRUE , progress=TRUE){
 	# process data
 	dat <- as.matrix(dat)
@@ -11,19 +11,48 @@ tetrachoric2 <- function( dat , delta=.007 , maxit = 1000000 ,
 	# calculate frequencies
 	dfr <- data.frame( "item1" = rep(1:I,I) , "item2" = rep(1:I, each=I ) )
 	h1 <- t( ( dat==1 ) ) %*% ( dat==0 )
-	dfr$f11 <- matrix( t( ( dat==1 ) ) %*% ( dat==1 ) , ncol=1 , byrow=T ) 
-	dfr$f10 <- matrix( t( ( dat==1 ) ) %*% ( dat==0 ) , ncol=1 , byrow=T ) 
-	dfr$f01 <- matrix( t( ( dat==0 ) ) %*% ( dat==1 ) , ncol=1 , byrow=T ) 
-	dfr$f00 <- matrix( t( ( dat==0 ) ) %*% ( dat==0 ) , ncol=1 , byrow=T ) 
+	dfr$f11 <- matrix( t( ( dat==1 ) ) %*% ( dat==1 ) , ncol=1 , byrow=TRUE ) + .5
+	dfr$f10 <- matrix( t( ( dat==1 ) ) %*% ( dat==0 ) , ncol=1 , byrow=TRUE ) + .5
+	dfr$f01 <- matrix( t( ( dat==0 ) ) %*% ( dat==1 ) , ncol=1 , byrow=TRUE ) + .5
+	dfr$f00 <- matrix( t( ( dat==0 ) ) %*% ( dat==0 ) , ncol=1 , byrow=TRUE ) + .5
+
+	# guessing
+#	if ( ! is.null(guess) ){
+#	   dfr0 <- dfr
+#	   dfr0$ftot <- dfr$f11 + dfr$f10 + dfr$f01 + dfr$f00
+#	   dfr$f00 <- dfr0$f00 / ( 1 - guess[dfr$item1 ] ) /  ( 1 - guess[dfr$item2 ] )
+#	   dfr$f01 <- ( (1 - guess[dfr$item2 ])* dfr0$f01 - guess[dfr$item2] * dfr0$f00 ) / 
+#						( 1 - guess[dfr$item1 ] ) /  ( 1 - guess[dfr$item2 ] )	
+#	   dfr$f10 <- ( (1 - guess[dfr$item1 ])* dfr0$f10 - guess[dfr$item1] * dfr0$f00 ) / 
+#						( 1 - guess[dfr$item1 ] ) /  ( 1 - guess[dfr$item2 ] )	
+#	   dfr$f11 <- dfr0$ftot - dfr$f00 - dfr$f01 - dfr$f10 - dfr$f11				
+#		}
+		
 	dfr$ftot <- dfr$f11 + dfr$f10 + dfr$f01 + dfr$f00
 	dfr$p11 <- dfr$f11 / dfr$ftot
-	dfr$pi1 <- ( dfr$f11 + dfr$f10 ) / dfr$ftot
-	dfr$pi2 <- ( dfr$f11 + dfr$f01 ) / dfr$ftot
+	dfr$pi1 <- ( dfr$f11 + dfr$f10 - 1 ) / dfr$ftot
+	dfr$pi2 <- ( dfr$f11 + dfr$f01 - 1) / dfr$ftot
 	# subdata of dfr
 	dfr <- dfr[ dfr$item1 > dfr$item2 , ]
 	dfr <- dfr[ dfr$ftot > 0 , ]
+	
+
+	
+	
 	dfr$qi1 <- qnorm( dfr$pi1)
 	dfr$qi2 <- qnorm( dfr$pi2)
+	
+    # method of Bonett
+    if ( method=="Bo" ){ 
+        dfr$pmin <- ifelse( dfr$pi1 < dfr$pi2 , dfr$pi1 , dfr$pi2 )
+        dfr$c <- ( 1 - abs( dfr$pi1 - dfr$pi2 ) / 5 - ( 0.5 - dfr$pmin)^2  ) / 2
+        dfr$omega <- ( dfr$f00 * dfr$f11 ) / ( dfr$f01 * dfr$f10)
+        dfr$r0 <- cos( pi / ( 1 + dfr$omega^( dfr$c )  ) )
+                    }	
+	
+	# method of Tucker
+	if ( method=="Tu"){
+	
 	# functions defined by Cengiz Zopluoglu   
 #	L <- function(r,h,k) {(1/(2*pi*sqrt(1-r^2)))*exp(-((h^2-2*h*k*r+k^2)/(2*(1-r^2))))}
 	L <- function(r,h,k) {(1/(2*pi*sqrt(1-r^2)))*exp(-((h^2-2*h*k*r+k^2)/(2*(1-r^2))))}
@@ -60,12 +89,13 @@ tetrachoric2 <- function( dat , delta=.007 , maxit = 1000000 ,
 					}
 			}
 	cat("\n")
+		}
 	TC <- matrix(NA , I , I )
 	diag(TC) <- 1
 	TC[ as.matrix(dfr[ , c("item1","item2") ] ) ] <- dfr$r0
 	TC[ as.matrix(dfr[ , c("item2","item1") ] ) ] <- dfr$r0
 	if (cor.smooth){ 
-		TC <- cor.smooth(TC) 
+		TC <- psych::cor.smooth(TC) 
 			    }
 	rownames(TC) <- colnames(TC) <- colnames(dat)
 	res <- list("tau"=tau , "rho" = TC )
